pub struct AgentDefinition {
pub identity: String,
pub name: String,
pub short_name: String,
pub aliases: Vec<String>,
pub adapter: AdapterKind,
pub command: String,
pub detect_command: Option<String>,
pub full_access_startup_argument: Option<String>,
pub active: bool,
}Expand description
A launchable agent entry.
Fields
identity: Stringname: Stringshort_name: Stringaliases: Vec<String>adapter: AdapterKindcommand: Stringdetect_command: Option<String>full_access_startup_argument: Option<String>Optional argument appended when launching a native adapter in its default full-access mode. This mirrors the Python catalog field while keeping custom adapters free to omit it.
active: boolImplementations