pub fn replay_trace(roster_size: usize, trace: &[AgentEvent]) -> SessionStateExpand description
Replay a normalized trace through the deterministic core reducer.
pub fn replay_trace(roster_size: usize, trace: &[AgentEvent]) -> SessionStateReplay a normalized trace through the deterministic core reducer.