pub fn reduce(state: &mut SessionState, event: AgentEvent) -> Vec<Effect>Expand description
Apply one normalized event. I/O and rendering are represented by effects, never performed in the reducer.
pub fn reduce(state: &mut SessionState, event: AgentEvent) -> Vec<Effect>Apply one normalized event. I/O and rendering are represented by effects, never performed in the reducer.