Module goal
codeswarm_
adapters
0.9.3
Module goal
Module Items
Structs
Enums
Constants
Functions
In crate codeswarm_
adapters
codeswarm_adapters
Module
goal
User-owned session goals, independent of provider sessions and relay limits.
Structs

Goal
Enums

Goal
Command
Goal
Status
Constants

GOAL_
USAGE
Functions

apply
Returns a human task to dispatch only for setting or resuming a goal.
prompt