pub struct RelayCancellation { /* private fields */ }Expand description
A clonable signal used by a terminal control loop to interrupt the active relay turn without borrowing the relay while its adapter is being polled.
Implementations