Module goal

Module goal 

User-owned session goals, independent of provider sessions and relay limits.

Structs

Goal

Enums

GoalCommand
GoalStatus

Constants

GOAL_USAGE

Functions

apply
Returns a human task to dispatch only for setting or resuming a goal.
prompt